@@ -77,7 +77,7 @@ function(x, col=rev(terrain.colors(255)), maxpixels=500000, levelplot=FALSE, new
 
 		if (levelplot) {
 			.levelplotraster(x, col=col, maxpixels=maxpixels, ...) 
-		} else if (!is.null(x@legend@colortable) & exists("rasterImage") ) {
+		} else if (length(x@legend@colortable) > 0) {
 			.plotCT(x, maxpixels=maxpixels, ...)
 		} else if (newstyle) {
 			.plot2(x, col=col, maxpixels=maxpixels, ...)
